﻿using System;
using Windows.ApplicationModel.Core;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.Core;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "ApplicationViewSwitcher 클래스 : TryShowAsStandaloneAsync 정적 메소드를 사용해 신규 윈도우 표시하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 신규 윈도우 표시 버튼 클릭시 처리하기 - showNewWindowButton_Click(sender, e)

        /// <summary>
        /// 신규 윈도우 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private async void showNewWindowButton_Click(object sender, RoutedEventArgs e)
        {
            CoreApplicationView view = CoreApplication.CreateNewView();

            int viewID = 0;

            await view.Dispatcher.RunAsync
            (
                CoreDispatcherPriority.Normal,
                () =>
                {
                    Frame frame = new Frame();

                    frame.Navigate(typeof(SamplePage), null);

                    Window.Current.Content = frame;

                    Window.Current.Activate();

                    viewID = ApplicationView.GetForCurrentView().Id;
                }
            );

            bool visible = await ApplicationViewSwitcher.TryShowAsStandaloneAsync(viewID);
        }

        #endregion
    }
}